@@ -71,7 +71,7 @@ setMethod("gpcm", signature(x="sep.pars"), function(x, cat, theta, dimensions, D
 		theta <- as.matrix(theta)
 		colnames(theta) <- "theta1"
 	}else if (dimensions>1) {
-		if (is.numeric(theta)) {
+		if (is.vector(theta)) {
 			tmp <- vector("list", dimensions)
 			for (i in 1:dimensions) {
 				tmp[[i]] <- theta
